@@ -5,6 +5,7 @@ from __future__ import annotations
 from threading import Lock
 from typing import TYPE_CHECKING, Dict, Iterable, Optional
 
+from pyatlan.client.constants import GET_KEYCLOAK_USER_ROLE_MAPPING
 from pyatlan.model.role import AtlanRole
 
 if TYPE_CHECKING:
@@ -24,6 +25,7 @@ class RoleCache:
         self.map_id_to_name: Dict[str, str] = {}
         self.map_name_to_id: Dict[str, str] = {}
         self.lock: Lock = Lock()
+        self._is_api_token_user: Optional[bool] = None
 
     def get_id_for_name(self, name: str) -> Optional[str]:
         """
@@ -34,6 +36,36 @@ class RoleCache:
         """
         return self._get_id_for_name(name=name)
 
+    def is_api_token_user(self) -> bool:
+        """
+        Check if the current user is authenticated via an API token or OAuth client.
+        This method checks for the presence of $api-token-default-access or $admin roles.
+
+        :returns: True if the user is an API token user, False otherwise
+        """
+        if self._is_api_token_user is not None:
+            return self._is_api_token_user
+
+        # Get current user to retrieve their UUID
+        current_user = self.client.user.get_current()
+
+        # Fetch role mappings for the current user
+        raw_json = self.client._call_api(
+            api=GET_KEYCLOAK_USER_ROLE_MAPPING.format_path(
+                {"user_uuid": current_user.id}
+            )
+        )
+
+        # Check if the user has $api-token-default-access or $admin roles
+        for role_mapping in raw_json["realmMappings"]:
+            role_name = role_mapping.get("name")
+            if role_name in ["$api-token-default-access", "$admin"]:
+                self._is_api_token_user = True
+                return self._is_api_token_user
+
+        self._is_api_token_user = False
+        return self._is_api_token_user
+
     def get_name_for_id(self, idstr: str) -> Optional[str]:
         """
         Translate the provided role GUID to the human-readable role name.
