@@ -2,7 +2,7 @@
 # Copyright 2022 Atlan Pte. Ltd.
 from __future__ import annotations
 
-from typing import Generator, Protocol, runtime_checkable
+from typing import Any, Generator, Protocol, runtime_checkable
 
 from urllib3.util.retry import Retry
 
@@ -19,7 +19,12 @@ CONNECTION_RETRY = Retry(
 @runtime_checkable
 class ApiCaller(Protocol):
     def _call_api(
-        self, api, query_params=None, request_obj=None, exclude_unset: bool = True
+        self,
+        api,
+        query_params=None,
+        request_obj=None,
+        exclude_unset: bool = True,
+        text_response: bool = False,
     ):
         pass
 
@@ -27,3 +32,15 @@ class ApiCaller(Protocol):
         self, max_retries: Retry = CONNECTION_RETRY
     ) -> Generator[None, None, None]:
         pass
+
+    def _s3_presigned_url_file_upload(self, api, upload_file: Any):
+        pass
+
+    def _azure_blob_presigned_url_file_upload(self, api, upload_file: Any):
+        pass
+
+    def _gcs_presigned_url_file_upload(self, api, upload_file: Any):
+        pass
+
+    def _presigned_url_file_download(self, api, file_path: str):
+        pass
