@@ -65,8 +65,10 @@ __PYATLAN_ASSETS__ = {
         "DbtSeed",
         "FivetranConnector",
         "Anomalo",
+        "alpha_DQRuleTemplate",
         "MonteCarlo",
         "Metric",
+        "alpha_DQRule",
         "Soda",
         "AIApplication",
         "AIModelVersion",
