@@ -63,13 +63,13 @@ class DatabricksAIModelContext(AIModel):
         "aiModelStatus", "aiModelStatus"
     )
     """
-    Status of the AI model
+    Status of the AI model.
     """
     AI_MODEL_VERSION: ClassVar[KeywordField] = KeywordField(
         "aiModelVersion", "aiModelVersion"
     )
     """
-    Version of the AI model
+    Version of the AI model.
     """
     ETHICAL_AI_PRIVACY_CONFIG: ClassVar[KeywordField] = KeywordField(
         "ethicalAIPrivacyConfig", "ethicalAIPrivacyConfig"
@@ -208,6 +208,12 @@ class DatabricksAIModelContext(AIModel):
     """
     Time (epoch) at which this asset was last profiled, in milliseconds.
     """
+    SQL_AI_MODEL_CONTEXT_QUALIFIED_NAME: ClassVar[KeywordField] = KeywordField(
+        "sqlAIModelContextQualifiedName", "sqlAIModelContextQualifiedName"
+    )
+    """
+    Unique name of the context in which the model versions exist, or empty if it does not exist within an AI model context.
+    """  # noqa: E501
 
     DBT_SOURCES: ClassVar[RelationField] = RelationField("dbtSources")
     """
@@ -274,6 +280,7 @@ class DatabricksAIModelContext(AIModel):
         "calculation_view_qualified_name",
         "is_profiled",
         "last_profiled_at",
+        "sql_a_i_model_context_qualified_name",
         "dbt_sources",
         "databricks_a_i_model_versions",
         "sql_dbt_models",
@@ -647,6 +654,24 @@ class DatabricksAIModelContext(AIModel):
             self.attributes = self.Attributes()
         self.attributes.last_profiled_at = last_profiled_at
 
+    @property
+    def sql_a_i_model_context_qualified_name(self) -> Optional[str]:
+        return (
+            None
+            if self.attributes is None
+            else self.attributes.sql_a_i_model_context_qualified_name
+        )
+
+    @sql_a_i_model_context_qualified_name.setter
+    def sql_a_i_model_context_qualified_name(
+        self, sql_a_i_model_context_qualified_name: Optional[str]
+    ):
+        if self.attributes is None:
+            self.attributes = self.Attributes()
+        self.attributes.sql_a_i_model_context_qualified_name = (
+            sql_a_i_model_context_qualified_name
+        )
+
     @property
     def dbt_sources(self) -> Optional[List[DbtSource]]:
         return None if self.attributes is None else self.attributes.dbt_sources
@@ -785,6 +810,9 @@ class DatabricksAIModelContext(AIModel):
         )
         is_profiled: Optional[bool] = Field(default=None, description="")
         last_profiled_at: Optional[datetime] = Field(default=None, description="")
+        sql_a_i_model_context_qualified_name: Optional[str] = Field(
+            default=None, description=""
+        )
         dbt_sources: Optional[List[DbtSource]] = Field(
             default=None, description=""
         )  # relationship
