@@ -57,13 +57,13 @@ class SnowflakeAIModelContext(AIModel):
         "aiModelStatus", "aiModelStatus"
     )
     """
-    Status of the AI model
+    Status of the AI model.
     """
     AI_MODEL_VERSION: ClassVar[KeywordField] = KeywordField(
         "aiModelVersion", "aiModelVersion"
     )
     """
-    Version of the AI model
+    Version of the AI model.
     """
     ETHICAL_AI_PRIVACY_CONFIG: ClassVar[KeywordField] = KeywordField(
         "ethicalAIPrivacyConfig", "ethicalAIPrivacyConfig"
@@ -202,6 +202,12 @@ class SnowflakeAIModelContext(AIModel):
     """
     Time (epoch) at which this asset was last profiled, in milliseconds.
     """
+    SQL_AI_MODEL_CONTEXT_QUALIFIED_NAME: ClassVar[KeywordField] = KeywordField(
+        "sqlAIModelContextQualifiedName", "sqlAIModelContextQualifiedName"
+    )
+    """
+    Unique name of the context in which the model versions exist, or empty if it does not exist within an AI model context.
+    """  # noqa: E501
 
     DBT_SOURCES: ClassVar[RelationField] = RelationField("dbtSources")
     """
@@ -267,6 +273,7 @@ class SnowflakeAIModelContext(AIModel):
         "calculation_view_qualified_name",
         "is_profiled",
         "last_profiled_at",
+        "sql_a_i_model_context_qualified_name",
         "dbt_sources",
         "sql_dbt_models",
         "dbt_tests",
@@ -622,6 +629,24 @@ class SnowflakeAIModelContext(AIModel):
             self.attributes = self.Attributes()
         self.attributes.last_profiled_at = last_profiled_at
 
+    @property
+    def sql_a_i_model_context_qualified_name(self) -> Optional[str]:
+        return (
+            None
+            if self.attributes is None
+            else self.attributes.sql_a_i_model_context_qualified_name
+        )
+
+    @sql_a_i_model_context_qualified_name.setter
+    def sql_a_i_model_context_qualified_name(
+        self, sql_a_i_model_context_qualified_name: Optional[str]
+    ):
+        if self.attributes is None:
+            self.attributes = self.Attributes()
+        self.attributes.sql_a_i_model_context_qualified_name = (
+            sql_a_i_model_context_qualified_name
+        )
+
     @property
     def dbt_sources(self) -> Optional[List[DbtSource]]:
         return None if self.attributes is None else self.attributes.dbt_sources
@@ -755,6 +780,9 @@ class SnowflakeAIModelContext(AIModel):
         )
         is_profiled: Optional[bool] = Field(default=None, description="")
         last_profiled_at: Optional[datetime] = Field(default=None, description="")
+        sql_a_i_model_context_qualified_name: Optional[str] = Field(
+            default=None, description=""
+        )
         dbt_sources: Optional[List[DbtSource]] = Field(
             default=None, description=""
         )  # relationship
