@@ -138,6 +138,8 @@ class AtlanConnectionCategory(str, Enum):
     SCHEMA_REGISTRY = "schema-registry"
     APP = "app"
     CUSTOM = "custom"
+    AI = "ai"
+    ERP = "erp"
 
 
 class AtlanConnectorType(str, Enum, metaclass=utils.ExtendableEnumMeta):
@@ -381,6 +383,8 @@ class AtlanConnectorType(str, Enum, metaclass=utils.ExtendableEnumMeta):
     CRATEDB = ("cratedb", AtlanConnectionCategory.DATABASE)
     KX = ("kx", AtlanConnectionCategory.DATABASE)
     DOCUMENTDB = ("documentdb", AtlanConnectionCategory.DATABASE)
+    AI = ("ai", AtlanConnectionCategory.AI)
+    SAP_ECC = ("sap-ecc", AtlanConnectionCategory.ERP)
 
 
 class AtlanCustomAttributePrimitiveType(str, Enum):
@@ -2429,6 +2433,15 @@ class OpenLineageEventType(Enum):
     OTHER = "OTHER"
 
 
+class alpha_DQRuleThresholdCompareOperator(str, Enum):
+    EQUAL = "EQ"
+    GREATER_THAN_EQUAL = "GTE"
+    LESS_THAN_EQUAL = "LTE"
+    BETWEEN = "BETWEEN"
+    GREATER_THAN = "GT"
+    LESS_THAN = "LT"
+
+
 # **************************************
 # CODE BELOW IS GENERATED NOT MODIFY  **
 # **************************************
@@ -2907,3 +2920,66 @@ class WorkflowType(str, Enum):
     PUBLICATION_MANAGEMENT = "PUBLICATION_MANAGEMENT"
     IMPACT_ANALYSIS = "IMPACT_ANALYSIS"
     REVOKE_DATA_ACCESS = "REVOKE_DATA_ACCESS"
+
+
+class alpha_DQDimension(str, Enum):
+    COMPLETENESS = "completeness"
+    TIMELINESS = "timeliness"
+    ACCURACY = "accuracy"
+    CONSISTENCY = "consistency"
+    UNIQUENESS = "uniqueness"
+    VALIDITY = "validity"
+    VOLUME = "volume"
+
+
+class alpha_DQEnvironmentSetupStatus(str, Enum):
+    NOT_STARTED = "NOT_STARTED"
+    IN_PROGRESS = "IN_PROGRESS"
+    SUCCESSFUL = "SUCCESSFUL"
+    FAILED = "FAILED"
+
+
+class alpha_DQResult(str, Enum):
+    PASS = "PASS"
+    FAIL = "FAIL"
+
+
+class alpha_DQRuleAlertPriority(str, Enum):
+    URGENT = "URGENT"
+    NORMAL = "NORMAL"
+    LOW = "LOW"
+
+
+class alpha_DQRuleStatus(str, Enum):
+    ACTIVE = "ACTIVE"
+    SUSPENDED = "SUSPENDED"
+
+
+class alpha_DQRuleTemplateMetricValueType(str, Enum):
+    ABSOLUTE = "ABSOLUTE"
+    PERCENTAGE = "PERCENTAGE"
+    TIME = "TIME"
+
+
+class alpha_DQRuleThresholdUnit(str, Enum):
+    PERCENTAGE = "PERCENTAGE"
+    SECONDS = "SECONDS"
+    MINUTES = "MINUTES"
+    HOURS = "HOURS"
+    DAYS = "DAYS"
+    WEEKS = "WEEKS"
+    MONTHS = "MONTHS"
+    YEARS = "YEARS"
+
+
+class alpha_DQScheduleType(str, Enum):
+    ON_DATA_CHANGE = "ON_DATA_CHANGE"
+    CRON = "CRON"
+    NOT_SCHEDULED = "NOT_SCHEDULED"
+
+
+class alpha_DQSourceSyncStatus(str, Enum):
+    SUCCESSFUL = "SUCCESSFUL"
+    FAILURE = "FAILURE"
+    IN_PROGRESS = "IN_PROGRESS"
+    WAITING_FOR_SCHEDULE = "WAITING_FOR_SCHEDULE"
