@@ -15,6 +15,7 @@ from pyatlan.model.enums import (
     FormFieldDimension,
     FormFieldType,
     SourceCostUnitType,
+    alpha_DQRuleThresholdUnit,
 )
 from pyatlan.model.utils import to_camel_case
 from pyatlan.utils import select_optional_set_fields, validate_required_fields
@@ -81,13 +82,6 @@ class AwsCloudWatchMetric(AtlanObject):
     aws_cloud_watch_metric_scope: str = Field(description="")
 
 
-class Histogram(AtlanObject):
-    """Description"""
-
-    boundaries: Set[float] = Field(description="")
-    frequencies: Set[float] = Field(description="")
-
-
 class Action(AtlanObject):
     """Description"""
 
@@ -97,6 +91,13 @@ class Action(AtlanObject):
     task_action_display_text: Optional[str] = Field(default=None, description="")
 
 
+class Histogram(AtlanObject):
+    """Description"""
+
+    boundaries: Set[float] = Field(description="")
+    frequencies: Set[float] = Field(description="")
+
+
 class ColumnValueFrequencyMap(AtlanObject):
     """Description"""
 
@@ -104,13 +105,6 @@ class ColumnValueFrequencyMap(AtlanObject):
     column_value_frequency: Optional[int] = Field(default=None, description="")
 
 
-class SourceTagAttachmentValue(AtlanObject):
-    """Description"""
-
-    tag_attachment_key: Optional[str] = Field(default=None, description="")
-    tag_attachment_value: Optional[str] = Field(default=None, description="")
-
-
 class BadgeCondition(AtlanObject):
     """Description"""
 
@@ -143,6 +137,48 @@ class BadgeCondition(AtlanObject):
     badge_condition_colorhex: Optional[str] = Field(default=None, description="")
 
 
+class SourceTagAttachmentValue(AtlanObject):
+    """Description"""
+
+    tag_attachment_key: Optional[str] = Field(default=None, description="")
+    tag_attachment_value: Optional[str] = Field(default=None, description="")
+
+
+class alpha_DQRuleTemplateConfig(AtlanObject):
+    """Description"""
+
+    alpha_dq_rule_template_config_base_dataset_qualified_name: Optional[str] = Field(
+        default=None, description=""
+    )
+    alpha_dq_rule_template_config_base_column_qualified_name: Optional[str] = Field(
+        default=None, description=""
+    )
+    alpha_dq_rule_template_config_reference_dataset_qualified_names: Optional[str] = (
+        Field(default=None, description="")
+    )
+    alpha_dq_rule_template_config_reference_column_qualified_names: Optional[str] = (
+        Field(default=None, description="")
+    )
+    alpha_dq_rule_template_config_threshold_object: Optional[str] = Field(
+        default=None, description=""
+    )
+    alpha_dq_rule_template_config_display_name: Optional[str] = Field(
+        default=None, description=""
+    )
+    alpha_dq_rule_template_config_custom_s_q_l: Optional[str] = Field(
+        default=None, description=""
+    )
+    alpha_dq_rule_template_config_dimension: Optional[str] = Field(
+        default=None, description=""
+    )
+    alpha_dq_rule_template_config_user_description: Optional[str] = Field(
+        default=None, description=""
+    )
+    alpha_dq_rule_template_advanced_settings: Optional[str] = Field(
+        default=None, description=""
+    )
+
+
 class StarredDetails(AtlanObject):
     """Description"""
 
@@ -213,15 +249,6 @@ class FormField(AtlanObject):
     form_field_options: Optional[Dict[str, str]] = Field(default=None, description="")
 
 
-class KafkaTopicConsumption(AtlanObject):
-    """Description"""
-
-    topic_name: Optional[str] = Field(default=None, description="")
-    topic_partition: Optional[str] = Field(default=None, description="")
-    topic_lag: Optional[int] = Field(default=None, description="")
-    topic_current_offset: Optional[int] = Field(default=None, description="")
-
-
 class DatabricksAIModelVersionMetric(AtlanObject):
     """Description"""
 
@@ -239,6 +266,15 @@ class DatabricksAIModelVersionMetric(AtlanObject):
     )
 
 
+class KafkaTopicConsumption(AtlanObject):
+    """Description"""
+
+    topic_name: Optional[str] = Field(default=None, description="")
+    topic_partition: Optional[str] = Field(default=None, description="")
+    topic_lag: Optional[int] = Field(default=None, description="")
+    topic_current_offset: Optional[int] = Field(default=None, description="")
+
+
 class SourceTagAttachment(AtlanObject):
     """Description"""
 
@@ -395,6 +431,29 @@ class AuthPolicyCondition(AtlanObject):
     policy_condition_values: Set[str] = Field(description="")
 
 
+class alpha_DQRuleConfigArguments(AtlanObject):
+    """Description"""
+
+    alpha_dq_rule_threshold_object: Optional[alpha_DQRuleThresholdObject] = Field(
+        default=None, description=""
+    )
+    alpha_dq_rule_config_arguments_raw: Optional[str] = Field(
+        default=None, description=""
+    )
+
+
+class alpha_DQRuleRangeForTesting(AtlanObject):
+    """Description"""
+
+    alpha_dq_rule_range_operator: Optional[str] = Field(default=None, description="")
+    alpha_dq_rule_lower_bound_for_testing: Optional[str] = Field(
+        default=None, description=""
+    )
+    alpha_dq_rule_upper_bound_for_testing: Optional[str] = Field(
+        default=None, description=""
+    )
+
+
 class DbtMetricFilter(AtlanObject):
     """Description"""
 
@@ -434,6 +493,18 @@ class GoogleLabel(AtlanObject):
     google_label_value: str = Field(description="")
 
 
+class alpha_DQRuleThresholdObject(AtlanObject):
+    """Description"""
+
+    alpha_dq_rule_threshold_compare_operator: Optional[str] = Field(
+        default=None, description=""
+    )
+    alpha_dq_rule_threshold_value: Optional[float] = Field(default=None, description="")
+    alpha_dq_rule_threshold_unit: Optional[alpha_DQRuleThresholdUnit] = Field(
+        default=None, description=""
+    )
+
+
 class PopularityInsights(AtlanObject):
     """Description"""
 
@@ -467,15 +538,17 @@ DbtJobRun.update_forward_refs()
 
 AwsCloudWatchMetric.update_forward_refs()
 
-Histogram.update_forward_refs()
-
 Action.update_forward_refs()
 
+Histogram.update_forward_refs()
+
 ColumnValueFrequencyMap.update_forward_refs()
 
+BadgeCondition.update_forward_refs()
+
 SourceTagAttachmentValue.update_forward_refs()
 
-BadgeCondition.update_forward_refs()
+alpha_DQRuleTemplateConfig.update_forward_refs()
 
 StarredDetails.update_forward_refs()
 
@@ -489,16 +562,20 @@ ResponseValue.update_forward_refs()
 
 FormField.update_forward_refs()
 
-KafkaTopicConsumption.update_forward_refs()
-
 DatabricksAIModelVersionMetric.update_forward_refs()
 
+KafkaTopicConsumption.update_forward_refs()
+
 SourceTagAttachment.update_forward_refs()
 
 AzureTag.update_forward_refs()
 
 AuthPolicyCondition.update_forward_refs()
 
+alpha_DQRuleConfigArguments.update_forward_refs()
+
+alpha_DQRuleRangeForTesting.update_forward_refs()
+
 DbtMetricFilter.update_forward_refs()
 
 AuthPolicyValiditySchedule.update_forward_refs()
@@ -507,6 +584,8 @@ MCRuleComparison.update_forward_refs()
 
 GoogleLabel.update_forward_refs()
 
+alpha_DQRuleThresholdObject.update_forward_refs()
+
 PopularityInsights.update_forward_refs()
 
 SourceTagAttribute.update_forward_refs()
